@@ -1,20 +1,22 @@
-import torchvision.transforms as T
-from torchvision import datasets
+from torchvision.datasets import MNIST
 
+from ..transforms.classification import get_mnist_transform, get_resnet_transform
 from ..utils import common_functions as c_f
-from ..utils.constants import IMAGENET_MEAN, IMAGENET_STD
-from ..utils.transforms import GrayscaleToRGB
+from .clipart1k import Clipart1kMultiLabel
 from .combined_source_and_target import CombinedSourceAndTargetDataset
 from .concat_dataset import ConcatDataset
+from .domainnet import DomainNet126
 from .mnistm import MNISTM
 from .office31 import Office31
 from .officehome import OfficeHome
 from .source_dataset import SourceDataset
 from .target_dataset import TargetDataset
+from .voc_multilabel import VOCMultiLabel
+from .voc_multilabel import get_labels_as_vector as voc_labels_as_vector
 
 
-def get_multiple(dataset_getter, domains, *args):
-    return ConcatDataset([dataset_getter(d, *args) for d in domains])
+def get_multiple(dataset_getter, domains, **kwargs):
+    return ConcatDataset([dataset_getter(domain=d, **kwargs) for d in domains])
 
 
 def get_datasets(
@@ -26,16 +28,18 @@ def get_datasets(
     return_target_with_labels=False,
     supervised=False,
     transform_getter=None,
+    **kwargs,
 ):
     def getter(domains, train, is_training):
         return get_multiple(
             dataset_getter,
             domains,
-            train,
-            is_training,
-            folder,
-            download,
-            transform_getter,
+            train=train,
+            is_training=is_training,
+            root=folder,
+            download=download,
+            transform_getter=transform_getter,
+            **kwargs,
         )
 
     if not src_domains and not target_domains:
@@ -74,68 +78,30 @@ def get_datasets(
     return output
 
 
-def get_mnist_transform(domain, *_):
-    if domain == "mnist":
-        return T.Compose(
-            [
-                T.Resize(32),
-                T.ToTensor(),
-                GrayscaleToRGB(),
-                T.Normalize(mean=IMAGENET_MEAN, std=IMAGENET_STD),
-            ]
-        )
-    elif domain == "mnistm":
-        return T.Compose(
-            [
-                T.ToTensor(),
-                T.Normalize(mean=IMAGENET_MEAN, std=IMAGENET_STD),
-            ]
-        )
-
-
-def _get_mnist_mnistm(domain, train, is_training, folder, download, transform_getter):
+def _get_mnist_mnistm(is_training, transform_getter, **kwargs):
     transform_getter = c_f.default(transform_getter, get_mnist_transform)
-    transform = transform_getter(domain, train, is_training)
+    domain = kwargs["domain"]
+    kwargs["transform"] = transform_getter(
+        domain=domain, train=kwargs["train"], is_training=is_training
+    )
+    kwargs.pop("domain")
     if domain == "mnist":
-        return datasets.MNIST(
-            folder, train=train, transform=transform, download=download
-        )
+        return MNIST(**kwargs)
     elif domain == "mnistm":
-        return MNISTM(folder, train, transform, download=download)
+        return MNISTM(**kwargs)
 
 
 def get_mnist_mnistm(*args, **kwargs):
     return get_datasets(_get_mnist_mnistm, *args, **kwargs)
 
 
-def get_resnet_transform(domain, train, is_training):
-    transform = [T.Resize(256)]
-    if is_training:
-        transform += [
-            T.RandomCrop(224),
-            T.RandomHorizontalFlip(),
-        ]
-    else:
-        transform += [T.CenterCrop(224)]
-
-    transform += [
-        T.ToTensor(),
-        T.Normalize(mean=IMAGENET_MEAN, std=IMAGENET_STD),
-    ]
-    return T.Compose(transform)
-
-
 def standard_dataset(cls):
-    def fn(domain, train, is_training, folder, download, transform_getter):
+    def fn(is_training, transform_getter, **kwargs):
         transform_getter = c_f.default(transform_getter, get_resnet_transform)
-        transform = transform_getter(domain, train, is_training)
-        return cls(
-            root=folder,
-            domain=domain,
-            train=train,
-            transform=transform,
-            download=download,
+        kwargs["transform"] = transform_getter(
+            domain=kwargs["domain"], train=kwargs["train"], is_training=is_training
         )
+        return cls(**kwargs)
 
     return fn
 
@@ -146,3 +112,32 @@ def get_office31(*args, **kwargs):
 
 def get_officehome(*args, **kwargs):
     return get_datasets(standard_dataset(OfficeHome), *args, **kwargs)
+
+
+def get_domainnet126(*args, **kwargs):
+    return get_datasets(standard_dataset(DomainNet126), *args, **kwargs)
+
+
+def _get_voc_multilabel(is_training, transform_getter, **kwargs):
+    # import here, because albumentations is an optional dependency
+    from ..transforms.detection import VOCTransformWrapper, get_voc_transform
+
+    transform_getter = c_f.default(transform_getter, get_voc_transform)
+    domain = kwargs["domain"]
+    transform = transform_getter(
+        domain=domain, train=kwargs["train"], is_training=is_training
+    )
+    kwargs["transforms"] = VOCTransformWrapper(transform, voc_labels_as_vector)
+    kwargs.pop("domain")
+    train = kwargs.pop("train")
+    if domain == "voc":
+        kwargs["image_set"] = "train" if train else "val"
+        return VOCMultiLabel(**kwargs)
+    elif domain == "clipart":
+        kwargs.pop("year", None)
+        kwargs["image_set"] = "train" if train else "test"
+        return Clipart1kMultiLabel(**kwargs)
+
+
+def get_voc_multilabel(*args, **kwargs):
+    return get_datasets(_get_voc_multilabel, *args, **kwargs)
