@@ -10,7 +10,7 @@ class FeaturesForDomainLossHook(FeaturesChainHook):
     """
     A [```FeaturesChainHook```][pytorch_adapt.hooks.features.FeaturesChainHook]
     that has options specific to
-    [```DomainLossHook```][pytorch_adapt.hooks.domain.DomainLossHook].
+    [```DomainLossHook```][pytorch_adapt.hooks.DomainLossHook].
     """
 
     def __init__(
@@ -89,7 +89,6 @@ class DomainLossHook(BaseWrapperHook):
         )
         d_hook = c_f.default(d_hook, DLogitsHook, {"domains": domains})
         f_out = f_hook.last_hook_out_keys
-        d_in = d_hook.in_keys
         d_hook.set_in_keys(f_out)
         self.check_fhook_dhook_keys(f_hook, d_hook, detach_features)
         self.hook = ChainHook(f_hook, d_hook)
@@ -100,9 +99,10 @@ class DomainLossHook(BaseWrapperHook):
         outputs = self.hook(inputs, losses)[0]
         labels = self.extract_domain_labels(inputs)
         for domain_name, labels in labels.items():
+            self.logger(f"Computing loss for {domain_name} domain")
             [dlogits] = c_f.extract(
                 [outputs, inputs],
-                c_f.filter(self.hook.out_keys, f"_dlogits$", [f"^{domain_name}"]),
+                c_f.filter(self.hook.out_keys, "_dlogits$", [f"^{domain_name}"]),
             )
             if dlogits.dim() > 1:
                 labels = labels.type(torch.long)
@@ -113,6 +113,7 @@ class DomainLossHook(BaseWrapperHook):
         return outputs, losses
 
     def extract_domain_labels(self, inputs):
+        self.logger("Expecting 'src_domain' and 'target_domain' in inputs")
         [src_domain, target_domain] = c_f.extract(
             inputs, ["src_domain", "target_domain"]
         )
